@@ -30,38 +30,34 @@ crew_controller_pbs <- function(
   seconds_interval = 0.25,
   seconds_timeout = 60,
   seconds_launch = 86400,
-  seconds_idle = Inf,
+  seconds_idle = 300,
   seconds_wall = Inf,
   seconds_exit = NULL,
+  retry_tasks = TRUE,
   tasks_max = Inf,
   tasks_timers = 0L,
   reset_globals = TRUE,
   reset_packages = FALSE,
   reset_options = FALSE,
   garbage_collection = FALSE,
-  launch_max = 5L,
-  verbose = FALSE,
-  command_submit = as.character(Sys.which("qsub")),
-  command_terminate = as.character(Sys.which("qdel")),
+  crashes_error = 5L,
+  r_arguments = c("--no-save", "--no-restore"),
+  options_metrics = crew::crew_options_metrics(),
+  options_cluster = crew.cluster::crew_options_pbs(),
+  verbose = NULL,
+  command_submit = NULL,
+  command_terminate = NULL,
   command_delete = NULL,
-  script_directory = tempdir(),
-  script_lines = character(0L),
-  pbs_cwd = TRUE,
-  pbs_log_output = "/dev/null",
+  script_directory = NULL,
+  script_lines = NULL,
+  pbs_cwd = NULL,
+  pbs_log_output = NULL,
   pbs_log_error = NULL,
-  pbs_log_join = TRUE,
+  pbs_log_join = NULL,
   pbs_memory_gigabytes_required = NULL,
   pbs_cores = NULL,
-  pbs_walltime_hours = 12
+  pbs_walltime_hours = NULL
 ) {
-  if (!is.null(seconds_exit)) {
-    crew::crew_deprecate(
-      name = "seconds_exit",
-      date = "2023-09-21",
-      version = "0.5.0.9002",
-      alternative = "none (no longer necessary)"
-    )
-  }
   client <- crew::crew_client(
     name = name,
     workers = workers,
@@ -71,7 +67,8 @@ crew_controller_pbs <- function(
     tls_enable = tls_enable,
     tls_config = tls_config,
     seconds_interval = seconds_interval,
-    seconds_timeout = seconds_timeout
+    seconds_timeout = seconds_timeout,
+    retry_tasks = retry_tasks
   )
   launcher <- crew_launcher_pbs(
     name = name,
@@ -86,8 +83,11 @@ crew_controller_pbs <- function(
     reset_packages = reset_packages,
     reset_options = reset_options,
     garbage_collection = garbage_collection,
-    launch_max = launch_max,
+    crashes_error = crashes_error,
     tls = tls,
+    r_arguments = r_arguments,
+    options_metrics = options_metrics,
+    options_cluster = options_cluster,
     verbose = verbose,
     command_submit = command_submit,
     command_terminate = command_terminate,
