@@ -34,7 +34,7 @@ crew_controller_slurm <- function(
   seconds_interval = 0.25,
   seconds_timeout = 60,
   seconds_launch = 86400,
-  seconds_idle = Inf,
+  seconds_idle = 300,
   seconds_wall = Inf,
   seconds_exit = NULL,
   retry_tasks = TRUE,
@@ -44,28 +44,24 @@ crew_controller_slurm <- function(
   reset_packages = FALSE,
   reset_options = FALSE,
   garbage_collection = FALSE,
-  launch_max = 5L,
-  verbose = FALSE,
-  command_submit = as.character(Sys.which("sbatch")),
-  command_terminate = as.character(Sys.which("scancel")),
+  crashes_error = 5L,
+  r_arguments = c("--no-save", "--no-restore"),
+  options_metrics = crew::crew_options_metrics(),
+  options_cluster = crew.cluster::crew_options_slurm(),
+  verbose = NULL,
+  command_submit = NULL,
+  command_terminate = NULL,
   command_delete = NULL,
-  script_directory = tempdir(),
-  script_lines = character(0L),
-  slurm_log_output = "/dev/null",
-  slurm_log_error = "/dev/null",
+  script_directory = NULL,
+  script_lines = NULL,
+  slurm_log_output = NULL,
+  slurm_log_error = NULL,
+  slurm_memory_gigabytes_required = NULL,
   slurm_memory_gigabytes_per_cpu = NULL,
   slurm_cpus_per_task = NULL,
-  slurm_time_minutes = 1440,
+  slurm_time_minutes = NULL,
   slurm_partition = NULL
 ) {
-  if (!is.null(seconds_exit)) {
-    crew::crew_deprecate(
-      name = "seconds_exit",
-      date = "2023-09-21",
-      version = "0.5.0.9002",
-      alternative = "none (no longer necessary)"
-    )
-  }
   client <- crew::crew_client(
     name = name,
     workers = workers,
@@ -91,8 +87,11 @@ crew_controller_slurm <- function(
     reset_packages = reset_packages,
     reset_options = reset_options,
     garbage_collection = garbage_collection,
-    launch_max = launch_max,
+    crashes_error = crashes_error,
     tls = tls,
+    r_arguments = r_arguments,
+    options_metrics = options_metrics,
+    options_cluster = options_cluster,
     verbose = verbose,
     command_submit = command_submit,
     command_terminate = command_terminate,
@@ -101,6 +100,7 @@ crew_controller_slurm <- function(
     script_lines = script_lines,
     slurm_log_output = slurm_log_output,
     slurm_log_error = slurm_log_error,
+    slurm_memory_gigabytes_required = slurm_memory_gigabytes_required,
     slurm_memory_gigabytes_per_cpu = slurm_memory_gigabytes_per_cpu,
     slurm_cpus_per_task = slurm_cpus_per_task,
     slurm_time_minutes = slurm_time_minutes,
