@@ -6,36 +6,37 @@ test_that("bad field in cluster launcher object", {
   skip_on_cran()
   x <- crew_launcher_cluster()
   private <- crew_private(x)
-  private$.verbose <- 2L
+  private$.options_cluster$verbose <- 2L
   expect_error(x$validate(), class = "crew_error")
 })
 
 test_that("active bindings", {
   x <- crew_launcher_cluster()
-  expect_false(x$verbose)
-  expect_equal(x$command_terminate, "")
-  expect_equal(x$script_lines, character(0L))
+  expect_s3_class(x$options_cluster, c("crew_options_cluster", "crew_options"))
 })
 
 test_that("SGE subclass mock job creates a tempdir() job script", {
   skip_on_cran()
   skip_on_os("windows")
   x <- crew_launcher_sge(
-    command_submit = "cat",
-    command_terminate = "echo",
-    script_lines = c("module load R", "echo 'start'"),
-    sge_cwd = TRUE,
-    sge_envvars = TRUE,
-    sge_log_output = "out_dir/",
-    sge_log_error = "err_dir/",
-    sge_log_join = FALSE,
-    sge_memory_gigabytes_required = 2.4,
-    sge_memory_gigabytes_limit = 8.4,
-    sge_cores = 2L,
-    sge_gpu = 1L
+    options_cluster = crew_options_sge(
+      command_submit = "cat",
+      command_terminate = "echo",
+      script_lines = c("module load R", "echo 'start'"),
+      cwd = TRUE,
+      envvars = TRUE,
+      log_output = "out_dir/",
+      log_error = "err_dir/",
+      log_join = FALSE,
+      memory_gigabytes_required = 2.4,
+      memory_gigabytes_limit = 8.4,
+      cores = 2L,
+      gpu = 1L
+    )
   )
   x$start(sockets = "my_socket")
-  expect_null(x$prefix)
+  private <- crew_private(x)
+  expect_null(private$.prefix)
   handle <- x$launch_worker(
     call = x$call(
       socket = "my_socket",
@@ -48,12 +49,11 @@ test_that("SGE subclass mock job creates a tempdir() job script", {
     worker = 1L,
     instance = "instance"
   )
-  private <- crew_private(x)
   private$.workers$handle[[1L]] <- handle
-  expect_false(is.null(x$prefix))
+  expect_false(is.null(private$.prefix))
   script <- path_script(
     dir = tempdir(),
-    prefix = x$prefix,
+    prefix = private$.prefix,
     launcher = x$name,
     worker = 1L
   )
@@ -85,22 +85,27 @@ test_that("SGE subclass mock job creates a custom job script", {
   skip_on_os("windows")
   dir <- file.path(tempfile(), basename(tempfile()), basename(tempfile()))
   x <- crew_launcher_sge(
-    command_submit = "cat",
-    command_terminate = "echo",
-    script_directory = dir,
-    script_lines = c("module load R", "echo 'start'"),
-    sge_cwd = TRUE,
-    sge_envvars = TRUE,
-    sge_log_output = "out_dir/",
-    sge_log_error = "err_dir/",
-    sge_log_join = FALSE,
-    sge_memory_gigabytes_required = 2.4,
-    sge_memory_gigabytes_limit = 8.4,
-    sge_cores = 2L,
-    sge_gpu = 1L
+    crashes_error = 10,
+    options_cluster = crew_options_sge(
+      command_submit = "cat",
+      command_terminate = "echo",
+      script_directory = dir,
+      script_lines = c("module load R", "echo 'start'"),
+      cwd = TRUE,
+      envvars = TRUE,
+      log_output = "out_dir/",
+      log_error = "err_dir/",
+      log_join = FALSE,
+      memory_gigabytes_required = 2.4,
+      memory_gigabytes_limit = 8.4,
+      cores = 2L,
+      gpu = 1L
+    )
   )
+  private <- crew_private(x)
   x$start(sockets = "my_socket")
-  expect_null(x$prefix)
+  expect_null(private$.prefix)
+  private$.workers$crashes <- 2L
   handle <- x$launch_worker(
     call = x$call(
       socket = "my_socket",
@@ -113,12 +118,11 @@ test_that("SGE subclass mock job creates a custom job script", {
     worker = 1L,
     instance = "instance"
   )
-  private <- crew_private(x)
   private$.workers$handle[[1L]] <- handle
-  expect_false(is.null(x$prefix))
+  expect_false(is.null(private$.prefix))
   script <- path_script(
     dir = dir,
-    prefix = x$prefix,
+    prefix = private$.prefix,
     launcher = x$name,
     worker = 1L
   )
@@ -145,11 +149,47 @@ test_that("SGE subclass mock job creates a custom job script", {
   expect_false(file.exists(script))
 })
 
-test_that("deprecate command_delete", {
+test_that("SGE subclass mock job prints retry message", {
   skip_on_cran()
-  expect_warning(
-    x <- crew_launcher_cluster(command_delete = "user_del"),
-    class = "crew_deprecate"
+  skip_on_os("windows")
+  dir <- file.path(tempfile(), basename(tempfile()), basename(tempfile()))
+  x <- crew_launcher_sge(
+    crashes_error = 10,
+    options_cluster = crew_options_sge(
+      command_submit = "rm",
+      command_terminate = "echo",
+      script_directory = dir,
+      script_lines = c("module load R", "echo 'start'"),
+      cwd = TRUE,
+      envvars = TRUE,
+      log_output = "out_dir/",
+      log_error = "err_dir/",
+      log_join = FALSE,
+      memory_gigabytes_required = 2.4,
+      memory_gigabytes_limit = 8.4,
+      cores = 2L,
+      gpu = 1L,
+      verbose = TRUE
+    )
+  )
+  private <- crew_private(x)
+  x$start(sockets = "my_socket")
+  private$.workers$crashes <- 2L
+  expect_message(
+    utils::capture.output(
+      handle <- x$launch_worker(
+        call = x$call(
+          socket = "my_socket",
+          launcher = x$name,
+          worker = 1L,
+          instance = "instance"
+        ),
+        name = "my_name",
+        launcher = x$name,
+        worker = 1L,
+        instance = "instance"
+      )
+    ),
+    class = "crew_message"
   )
-  expect_equal(x$command_terminate, "user_del")
 })
