@@ -5,11 +5,13 @@ test_that("valid simple crew_launcher_slurm()", {
 test_that("valid populated crew_launcher_slurm()", {
   expect_silent(
     crew_launcher_slurm(
-      script_lines = c("module load R", "echo 'start'"),
-      slurm_log_output = "log1",
-      slurm_log_error = "log2",
-      slurm_memory_gigabytes_per_cpu = NULL,
-      slurm_cpus_per_task = NULL
+      options_cluster = crew_options_slurm(
+        script_lines = c("module load R", "echo 'start'"),
+        log_output = "log1",
+        log_error = "log2",
+        memory_gigabytes_per_cpu = NULL,
+        cpus_per_task = NULL
+      )
     )
   )
 })
@@ -17,7 +19,7 @@ test_that("valid populated crew_launcher_slurm()", {
 test_that("invalid crew_launcher_slurm(): SLURM field", {
   x <- crew_launcher_slurm()
   private <- crew_private(x)
-  private$.slurm_cpus_per_task <- - 1L
+  private$.options_cluster$cpus_per_task <- - 1L
   expect_error(x$validate(), class = "crew_error")
 })
 
@@ -29,31 +31,37 @@ test_that("invalid crew_launcher_slurm(): non-SLURM field", {
 })
 
 test_that("crew_launcher_slurm() script() nearly empty", {
-  x <- crew_launcher_slurm(slurm_time_minutes = NULL)
+  x <- crew_launcher_slurm(
+    options_cluster = crew_options_slurm(time_minutes = NULL)
+  )
   lines <- c(
     "#!/bin/sh",
     "#SBATCH --job-name=a_job",
     "#SBATCH --output=/dev/null",
     "#SBATCH --error=/dev/null"
   )
-  expect_equal(x$script(name = "a_job"), lines)
+  expect_equal(x$script(name = "a_job", attempt = 1L), lines)
 })
 
 test_that("crew_launcher_slurm() script() all lines", {
   x <- crew_launcher_slurm(
-    script_lines = c("module load R", "echo 'start'"),
-    slurm_log_output = "log1",
-    slurm_log_error = "log2",
-    slurm_memory_gigabytes_per_cpu = 2.096,
-    slurm_cpus_per_task = 2,
-    slurm_time_minutes = 57
+    options_cluster = crew_options_slurm(
+      script_lines = c("module load R", "echo 'start'"),
+      log_output = "log1",
+      log_error = "log2",
+      memory_gigabytes_required = 4.1,
+      memory_gigabytes_per_cpu = 2.096,
+      cpus_per_task = 2,
+      time_minutes = 57
+    )
   )
-  out <- x$script(name = "this_job")
+  out <- x$script(name = "this_job", attempt = 1L)
   exp <- c(
     "#!/bin/sh",
     "#SBATCH --job-name=this_job",
     "#SBATCH --output=log1",
     "#SBATCH --error=log2",
+    "#SBATCH --mem=4198M",
     "#SBATCH --mem-per-cpu=2146M",
     "#SBATCH --cpus-per-task=2",
     "#SBATCH --time=57",
@@ -74,9 +82,11 @@ test_that(".args_terminate()", {
 
 test_that("deprecate command_delete", {
   skip_on_cran()
-  expect_warning(
-    x <- crew_launcher_slurm(command_delete = "user_del"),
-    class = "crew_deprecate"
+  suppressWarnings(
+    expect_warning(
+      x <- crew_launcher_slurm(command_delete = "user_del"),
+      class = "crew_deprecate"
+    )
   )
-  expect_equal(x$command_terminate, "user_del")
+  expect_equal(x$options_cluster$command_terminate, "user_del")
 })
